package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.TmstruckFeign;
import com.steerinfo.dil.service.ITmstruckWeightResultService;
import com.steerinfo.dil.service.impl.TmstruckWeightResultServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.text.ParseException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/10/25 17:34
 * @Version:V2.0
 */
@RestController
@RequestMapping("/${api.version}/tmstruckweightresult")
public class TmstruckWeightResultController extends BaseRESTfulController {

    @Autowired
    TmstruckWeightResultServiceImpl tmstruckWeightResultServiceImpl;

    @Autowired
    TmstruckFeign tmstruckFeign;


    /**
     * 接收达钢计量数据
     * @Author TXF
     * @Date 2022/2/9 15:04
     * @param mapList
     * @return
     **/
    @ApiModelProperty(value = "接收计量实绩")
    @ApiOperation(value = "接收计量实绩")
    @ApiParam(name = "orderNumber")
    @ApiImplicitParams({
            @ApiImplicitParam(
                    name = "orderNumber", value = "运输订单号", required = true, dataType = "String"
            ),
            @ApiImplicitParam(
                    name = "resultCalculateNumber", value = "计皮/计毛汽车衡编号", required = true, dataType = "String"
            ),
            @ApiImplicitParam(
                    name = "resultWeight", value = "皮重或者毛重", required = true, dataType = "Double"
            ),
            @ApiImplicitParam(
                    name = "resultWeightTime", value = "计皮/计毛时间", required = true, dataType = "String"
            ),
            @ApiImplicitParam(
                    name = "resultNetWeight", value = "净重", required = true, dataType = "Double"
            ), @ApiImplicitParam(
            name = "resultPoundNo", value = "磅单号", required = true, dataType = "String"
    ), @ApiImplicitParam(
            name = "weightType", value = "计皮/计毛", required = true, dataType = "String"
    )
    }
    )
    @PostMapping("/receiveTmsTruckWeightResultByDaGang")
    public RESTfulResult receiveTmsTruckWeightResultByDaGang(@RequestBody(required = false) List<Map<String, Object>> mapList) {
        String s = tmstruckWeightResultServiceImpl.receiveTmsTruckWeightResultByDaGang(mapList);
        if(!"成功".equals(s.substring(s.length() - 2))){
            return failed(s);
        }
        return success(s);
    }

    /**
     * 接收达兴计量实绩(计量实绩)
     * @param mapList
     * @return
     */
        @PostMapping("/receiveTmsTruckWeightResult")
    public RESTfulResult receiveTmsTruckWeightResult(@RequestBody(required = false) List<Map<String, Object>> mapList) {
        String mesStr = tmstruckWeightResultServiceImpl.receiveTmsTruckWeightResultByDaXing(mapList);
        if(!"成功".equals(mesStr.substring(mesStr.length() - 2))){
            return failed(mesStr);
        }
        return success(mesStr);
    }

    /**
     * 联动
     * @param mapList
     * @return
     */
    @PostMapping("/linkageDeleteTransportOrder")
    public RESTfulResult linkageDeleteTransportOrder(@RequestBody(required = false) List<Map<String, Object>> mapList) {
        String s = null;
        try {
            s = tmstruckWeightResultServiceImpl.linkageDeleteTransportOrder(mapList);
            if("success".equals(s)){
                return success(s);
            }
            return failed(s);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return success(s);
    }

    /**
     * 计量退货异常
     * @param orderNo
     * @return
     */
    @PostMapping("/abnormalReturn")
    @ApiOperation("value=触发退货实绩")
    @ApiImplicitParam(name = "orderNo",value = "运输订单号",required = true,dataType = "String")
    public RESTfulResult sendAbnormalReturn(String orderNo){
        Map<String, Object> map = new HashMap<>();
        map.put("purchOrder",orderNo);
        return success(tmstruckFeign.sendAbnormalReturn(map));
    }

    @PostMapping("checkOrder")
    @ApiOperation(value = "检查钢材运单是否正确")
    public Boolean checkOrder(@RequestBody(required = false) Map<String,Object> map) {
        return tmstruckWeightResultServiceImpl.checkOrder(map);
    }

    @PostMapping("/linkageDeleteTransportOrder2")
    public RESTfulResult linkageDeleteTransportOrder2(@RequestBody(required = false) Map<String, Object> map) {
        String s = null;
        try {
            s = tmstruckWeightResultServiceImpl.linkageDeleteTransportOrder2(map);
            if(s != null && s.contains("error")) {
                return failed(s);
            }else{
                return success(s);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return success(s);
    }

    @PostMapping("testJarSuccess")
    public RESTfulResult testJarSuccess() {
        return success("jar包发布成功");
    }

    /**
     * 根据车牌号修改运输订单号并返回
     * @param map
     * @return
     */
    @PostMapping("/changeOrderNumber")
    public RESTfulResult changeOrderNumber(@RequestBody(required = false) Map<String, Object> map) {
        String s = null;
        try {
            s = tmstruckWeightResultServiceImpl.changeOrderNumber(map);
        } catch (Exception e) {
            e.printStackTrace();
            if(e.getMessage()==null || e.getMessage().contains("Exception")){
                return failed("未知异常");
            }else{
                return failed(e.getMessage());
            }
        }
        return success(s);
    }

    @PostMapping("/queryApoByOrderNo")
    public List<Map<String,Object>> queryApoByOrderNo(@RequestBody Map<String,Object> map){
        List<Map<String,Object>> mapList = new ArrayList<>();
        List<String> orderNos = (List<String>)map.get("orderNos");
        try {
            mapList = tmstruckWeightResultServiceImpl.queryApoByOrderNo(orderNos);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return mapList;
    }
}
